# Changelog

## [2.0.5a2](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.5a2) (2025-10-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.5a1...2.0.5a2)

**Closed issues:**

- Does this project support custom AI Agent APIs? [\#726](https://github.com/OpenVoiceOS/ovos-core/issues/726)

**Merged pull requests:**

- translated ovos core [\#729](https://github.com/OpenVoiceOS/ovos-core/pull/729) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))

## [2.0.5a1](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.5a1) (2025-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.4a5...2.0.5a1)

**Merged pull requests:**

- fix: less requirements [\#724](https://github.com/OpenVoiceOS/ovos-core/pull/724) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.4a5](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.4a5) (2025-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.4a4...2.0.4a5)

**Closed issues:**

- ovos-core should restart itself when it detects a new skill [\#720](https://github.com/OpenVoiceOS/ovos-core/issues/720)

**Merged pull requests:**

- Fix/orjson optional [\#722](https://github.com/OpenVoiceOS/ovos-core/pull/722) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.4a4](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.4a4) (2025-06-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.4a3...2.0.4a4)

**Merged pull requests:**

- active skill end2end tests [\#717](https://github.com/OpenVoiceOS/ovos-core/pull/717) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.4a3](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.4a3) (2025-06-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.4a2...2.0.4a3)

**Merged pull requests:**

- improve skill shutdown [\#716](https://github.com/OpenVoiceOS/ovos-core/pull/716) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.4a2](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.4a2) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.4a1...2.0.4a2)

**Merged pull requests:**

- refactor: launcher args [\#714](https://github.com/OpenVoiceOS/ovos-core/pull/714) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.4a1](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.4a1) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.3a2...2.0.4a1)

**Merged pull requests:**

- fix: converse\_routing [\#712](https://github.com/OpenVoiceOS/ovos-core/pull/712) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.3a2](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.3a2) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.3a1...2.0.3a2)

**Merged pull requests:**

- tests: test cancel plugin [\#710](https://github.com/OpenVoiceOS/ovos-core/pull/710) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.3a1](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.3a1) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.2a2...2.0.3a1)

**Merged pull requests:**

- fix: stop message.context source/destination [\#706](https://github.com/OpenVoiceOS/ovos-core/pull/706) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.2a2](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.2a2) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.2a1...2.0.2a2)

**Merged pull requests:**

- Update ovos-config requirement from \<2.0.0,\>=0.0.13 to \>=0.0.13,\<3.0.0 in /requirements [\#707](https://github.com/OpenVoiceOS/ovos-core/pull/707) ([dependabot[bot]](https://github.com/apps/dependabot))

## [2.0.2a1](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.2a1) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.1a2...2.0.2a1)

**Merged pull requests:**

- fix: improve language disambiguation [\#704](https://github.com/OpenVoiceOS/ovos-core/pull/704) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.1a2](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.1a2) (2025-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.1a1...2.0.1a2)

**Merged pull requests:**

- refactor: improve\_stop [\#702](https://github.com/OpenVoiceOS/ovos-core/pull/702) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.1a1](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.1a1) (2025-06-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/2.0.0a1...2.0.1a1)

**Merged pull requests:**

- fix: minimum requirements + add galician skills extras [\#699](https://github.com/OpenVoiceOS/ovos-core/pull/699) ([JarbasAl](https://github.com/JarbasAl))

## [2.0.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/2.0.0a1) (2025-06-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.5.1a1...2.0.0a1)

**Breaking changes:**

- refactor!: drop old pipeline plugins and deprecated methods [\#690](https://github.com/OpenVoiceOS/ovos-core/pull/690) ([JarbasAl](https://github.com/JarbasAl))

## [1.5.1a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.5.1a1) (2025-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.5.0a3...1.5.1a1)

**Merged pull requests:**

- fix: skills-internet.txt [\#695](https://github.com/OpenVoiceOS/ovos-core/pull/695) ([JarbasAl](https://github.com/JarbasAl))

## [1.5.0a3](https://github.com/OpenVoiceOS/ovos-core/tree/1.5.0a3) (2025-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.5.0a2...1.5.0a3)

**Merged pull requests:**

- refactor: ovoscope [\#691](https://github.com/OpenVoiceOS/ovos-core/pull/691) ([JarbasAl](https://github.com/JarbasAl))

## [1.5.0a2](https://github.com/OpenVoiceOS/ovos-core/tree/1.5.0a2) (2025-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.5.0a1...1.5.0a2)

**Merged pull requests:**

- publish coverage report under gh-pages [\#692](https://github.com/OpenVoiceOS/ovos-core/pull/692) ([JarbasAl](https://github.com/JarbasAl))

## [1.5.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.5.0a1) (2025-05-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.4.0a1...1.5.0a1)

**Merged pull requests:**

- feat: intent transformers [\#686](https://github.com/OpenVoiceOS/ovos-core/pull/686) ([JarbasAl](https://github.com/JarbasAl))

## [1.4.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.4.0a1) (2025-05-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.3.1...1.4.0a1)

**Merged pull requests:**

- feat: m2v pipeline [\#681](https://github.com/OpenVoiceOS/ovos-core/pull/681) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
